.. shephard documentation master file, created by
   sphinx-quickstart on Thu Mar 15 13:55:56 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to shephard's documentation!
=========================================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   overview
   getting_started
   proteome
   protein
   domain
   site
   track
   shephard_file_types
   interfaces
   tools
   apis
   code_convention



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
